@@ -43,7 +43,7 @@ class FfmpegProcess:
 
         if ffmpeg_output_file is None:
             os.makedirs("ffmpeg_output", exist_ok=True)
-            ffmpeg_output_file = os.path.join("ffmpeg_output", f"[{Path(filepath).name}].txt")
+            ffmpeg_output_file = os.path.join("ffmpeg_output", f"[{Path(self._filepath).name}].txt")
 
         with open(ffmpeg_output_file, "w") as f:
             pass
@@ -53,11 +53,13 @@ class FfmpegProcess:
 
         if self._can_get_duration:
             print('IN DURATION')
-            popen_args.append(stdout=subprocess.PIPE)
-            popen_args.append(stderr=f)
-
+    
             with open(ffmpeg_output_file, "a") as f:
-                self._process = subprocess.Popen(*popen_args)
+                self._process = subprocess.Popen(
+                    self._ffmpeg_args,
+                    stdout=subprocess.PIPE,
+                    stderr=f
+                )
 
             progress_bar = tqdm(
                 total=duration_secs,
@@ -68,7 +70,7 @@ class FfmpegProcess:
             previous_seconds_processed = 0
         else:
             print('ELSE')
-            self._process = subprocess.Popen(*popen_args)
+            self._process = subprocess.Popen(self._ffmpeg_args)
 
         try:
             while self._process.poll() is None:
